/*
 *	XError()	-	catches X errors and handles them
 *
 *	RCS:
 *		$Revision$
 *		$Date$
 *
 *	Security:
 *		Unclassified
 *
 *	Description:
 *		This function catches X -lib errors and handles them.  It forgives
 *		the non-fatal errors.  If no error is handled, the application will
 *		exit with the error
 *
 *	Input Parameters:
 *		type	identifier	description
 *
 *		text
 *
 *	Output Parameters:
 *		type	identifier	description
 *
 *		text
 *
 *	Return Values:
 *		value	description
 *		0 - if the error is non-fatal
 *		-1 - exits if the error is fatal
 *
 *	Side Effects:
 *		text
 *
 *	Limitations and Comments:
 *		text
 *
 *	Development History:
 *		when	who		why
 *	2/04/94,	mm,		while freeing colors, BadAccess was happening.
 */
#include <xhead.h>
#include <X11/Xproto.h>
#include "xsf.h"

int XError (display, error)
Display *display;
XErrorEvent
	*error;
{
	int xerrcode;
	char buf[128];

	xerrcode = error->error_code;

	if (xerrcode == BadAlloc ||
		  (xerrcode == BadAccess && error->request_code==88)) return (False);
	
	else
	{
        switch (error->request_code)
        {
            case X_GetGeometry:
            {
                if (error->error_code == BadDrawable)
                    return (False);
                break;
            }

            case X_GetWindowAttributes:
            case X_QueryTree:
            {
                if (error->error_code == BadWindow)
                    return (False);
                break;
            }

            case X_QueryColors:
            {
                if (error->error_code == BadValue)
                    return(False);
                break;
            }
        }
/*
		XGetErrorText (display, xerrcode, buf, 128);
        (void) fprintf (stderr," -------------------------------------\n");
        (void) fprintf (stderr," Miv Error Handler:\n");
        (void) fprintf (stderr," Fatal X Error!\n");
        (void) fprintf (stderr," Error Type: %s\n", buf);
        (void) fprintf (stderr," Major Code: %d\n", error->request_code);
        (void) fprintf (stderr," -------------------------------------\n");
		exit(-1);
*/
	}
    XGetErrorText (display, xerrcode, buf, 128);
    (void) fprintf (stderr," mxhowfont Non-fatal XError..Handling!\n");
    (void) fprintf (stderr," Error Type: %s\n", buf);
    (void) fprintf (stderr," Major Code: %d\n", error->request_code);
	return (True);
}
